package com.supervision.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.supervision.domain.UserDetail;
import com.supervision.dto.AgentChatReqDTO;
import com.supervision.dto.AgentInfoDTO;
import com.supervision.dto.ChatResponseDTO;
import com.supervision.dto.R;
import com.supervision.service.AgentService;
import com.supervision.util.UserUtil;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;
import reactor.core.publisher.Flux;

@Slf4j
@RestController
@RequestMapping("/agent")
@RequiredArgsConstructor
public class AgentController {

    private final AgentService agentService;

    /**
     * 流式智能体问答
     * @param agentChatReqDTO agentChatReqDTO
     * @return
     */
    @PostMapping(value = "/streamChat", produces = MediaType.TEXT_EVENT_STREAM_VALUE)
    public Flux<ChatResponseDTO> streamChat(@RequestBody AgentChatReqDTO agentChatReqDTO) {
        UserDetail userDetail = UserUtil.currentUser();
        agentChatReqDTO.setUserId(userDetail.getUserId());
        return agentService.streamChat(agentChatReqDTO);
    }

    /**
     * 分页查询数字人列表
     * @param page 当前页码
     * @param pageSize 每页大小
     * @return
     */
    @GetMapping("/pageList")
    public R<IPage<AgentInfoDTO>> pageList(@RequestParam (name = "page", required = false,defaultValue = "1") Integer page,
                                           @RequestParam (name = "pageSize", required = false,defaultValue = "10") Integer pageSize) {

        IPage<AgentInfoDTO> paged = agentService.pageList(page, pageSize);
        return R.ok(paged);
    }


}
