package com.supervision.controller;

import cn.hutool.core.lang.Assert;
import com.supervision.domain.SysUser;
import com.supervision.dto.R;
import com.supervision.dto.UserDTO;
import com.supervision.service.SysUserService;
import lombok.RequiredArgsConstructor;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.web.bind.annotation.*;

/**
 * 用户控制器，用于处理用户相关接口
 */
@RestController
@RequestMapping("/user")
@RequiredArgsConstructor
public class UserController {

    private final SysUserService sysUserService;

    /**
     * 查看当前用户详情接口
     *
     * @return 当前登录用户的详细信息，如果用户不存在，则返回 404
     */
    @GetMapping("/me")
    public R<SysUser> getCurrentUserDetails() {
        Authentication authentication = SecurityContextHolder.getContext().getAuthentication();
        String username = authentication.getName();
        SysUser user = sysUserService.getByUsername(username);
        Assert.notNull(user, "用户不存在");
        user.setPassword(null);
        return R.ok(user);
    }


    /**
     * 更新用户信息
     * @param user 用户信息
     * @return
     */
    @PostMapping("/update")
    public R<Boolean> updateUser(@RequestBody UserDTO user) {
        Assert.notEmpty(user.getUserName(), "用户名不能为空");
        Boolean success = sysUserService.updateUser(user);
        return R.ok(success);
    }
}
