package com.supervision.dto;

import cn.hutool.core.lang.UUID;
import cn.hutool.core.util.StrUtil;
import com.supervision.domain.AgentDialogueLog;
import lombok.Data;
import java.time.Duration;
import java.time.LocalDateTime;

@Data
public class AgentDialogueLogDTO {

    /**
     * 对话日志id
     */
    private String id;

    /**
     * 用户id
     */
    private String userId;

    /**
     * 对话id
     */
    private String conversationId;

    /**
     * 用户输入
     */
    private String userInput;

    /**
     * 系统输出
     */
    private String systemOut;

    /**
     * 耗时
     */
    private Long timeCost;

    /**
     * 回答内容类型 0：正常回答 1：异常回答
     */
    private Integer answerType = 0;

    /**
     * 智能体id
     */
    private String agentId;

    /**
     * 问题创建时间
     */
    private LocalDateTime createTime;

    public AgentDialogueLogDTO() {
    }

    public AgentDialogueLogDTO(AgentChatReqDTO agentChatReqDTO) {
        this.userId = agentChatReqDTO.getUserId();
        if (StrUtil.isEmpty(agentChatReqDTO.getConversationId())){
            this.conversationId = UUID.fastUUID().toString();// 生成一个新的对话ID
        } else {
            this.conversationId = agentChatReqDTO.getConversationId();
        }
        this.agentId = agentChatReqDTO.getAgentCode();
        this.userInput = agentChatReqDTO.getQuery();
        this.createTime = LocalDateTime.now();
    }

    public AgentDialogueLog toDialogueLog(){
        AgentDialogueLog dialogueLog = new AgentDialogueLog();
        dialogueLog.setId(this.id);
        dialogueLog.setUserId(this.userId);
        dialogueLog.setAgentId(this.agentId);
        dialogueLog.setAnswerType(this.answerType);
        dialogueLog.setConversationId(this.conversationId);
        dialogueLog.setUserInput(this.userInput);
        dialogueLog.setSystemOut(this.systemOut);
        if (null != this.createTime){
            dialogueLog.setTimeCost(Duration.between(this.createTime, LocalDateTime.now()).toMillis());
        }
        return dialogueLog;
    }
}
