package com.supervision.service.impl;

import cn.hutool.core.lang.Assert;
import cn.hutool.json.JSONUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.supervision.domain.LivetalkingChatDTO;
import com.supervision.domain.DigitalHuman;
import com.supervision.domain.DigitalHumanDialogueLog;
import com.supervision.domain.VoiceInfo;
import com.supervision.dto.DanmakuMessage;
import com.supervision.dto.DigitalHumanDTO;
import com.supervision.dto.DigitalHumanVoiceDTO;
import com.supervision.service.DigitalHumanDialogueLogService;
import com.supervision.service.LivetalkingService;
import com.supervision.service.VoiceInfoService;
import com.supervision.service.danmaku.DanmakuPublisher;
import com.supervision.service.danmaku.DigitalHumanManageService;
import com.supervision.service.DigitalHumanService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

@Slf4j
@Service
@RequiredArgsConstructor
public class DigitalHumanManageServiceImpl implements DigitalHumanManageService {

    private final DigitalHumanService digitalHumanService;

    private final LivetalkingService livetalkingService;

    private final VoiceInfoService voiceInfoService;

    private final DigitalHumanDialogueLogService dialogueLogService;
    @Override
    public IPage<DigitalHumanDTO> pageList(Integer page, Integer pageSize) {

        Page<DigitalHuman> paged = digitalHumanService.page(Page.of(page, pageSize));
        return paged.convert(DigitalHumanDTO::new);
    }

    @Override
    public void setVoice(DigitalHumanVoiceDTO digitalHumanVoiceDTO) {

        VoiceInfo voiceInfo = voiceInfoService.getById(digitalHumanVoiceDTO.getVoiceId());
        Assert.notNull(voiceInfo, "语音信息不存在");
        livetalkingService.setVoice(voiceInfo.getVoiceCode(), digitalHumanVoiceDTO.getDigitalHumanId());
    }

    @Override
    public void chatCallBack(LivetalkingChatDTO digitalHumanVoiceDTO) {
        // 这里可以添加处理聊天回调的逻辑
        log.info("Received chat callback: {}", JSONUtil.toJsonStr(digitalHumanVoiceDTO));

        DigitalHumanDialogueLog dialogueLog = new DigitalHumanDialogueLog();
        dialogueLog.setId(digitalHumanVoiceDTO.getMessageId());
        dialogueLog.setDigitalHumanId(digitalHumanVoiceDTO.getHumanId());
        dialogueLog.setUserInput(digitalHumanVoiceDTO.getQuery());
        dialogueLog.setSystemOut(digitalHumanVoiceDTO.getAnswer());
        dialogueLogService.updateById(dialogueLog);

        // 消息推送到弹幕系统
        DanmakuMessage danmakuMessage = new DanmakuMessage();
        danmakuMessage.setContent(digitalHumanVoiceDTO.getAnswer());
        danmakuMessage.setRoomId(digitalHumanVoiceDTO.getRoomId());
        danmakuMessage.setUserId(digitalHumanVoiceDTO.getHumanId());
        danmakuMessage.setNickname("智能助手");
        danmakuMessage.setType("1");
        DanmakuPublisher.getInstance().publish(danmakuMessage);
    }

}
