package com.supervision.service.impl;

import cn.hutool.core.lang.Assert;
import com.supervision.domain.SysByteArray;
import com.supervision.service.FileService;
import com.supervision.service.SysByteArrayService;
import jakarta.servlet.http.HttpServletResponse;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;
import java.io.IOException;

@Slf4j
@Service
@RequiredArgsConstructor
public class SysFileServiceImpl implements FileService {

    private final SysByteArrayService sysByteArrayService;
    @Override
    public String upload(MultipartFile file) throws IOException {

        SysByteArray byteArray = new SysByteArray();
        byteArray.setFileName(file.getOriginalFilename());
        byteArray.setBytes(file.getBytes());
        byteArray.setSize(file.getSize());
        byteArray.setContentType(file.getContentType());
        sysByteArrayService.save(byteArray);
        return byteArray.getId();
    }

    @Override
    public void downLoad(String fileId, HttpServletResponse response) {
        Assert.notEmpty(fileId, "文件ID不能为空");
        SysByteArray byteArray = sysByteArrayService.getById(fileId);
        Assert.notNull(byteArray, "文件不存在或已被删除");
        response.setContentType(byteArray.getContentType());
        response.setHeader("Content-Disposition", "attachment; filename=\"" + byteArray.getFileName() + "\"");
        try {
            response.getOutputStream().write(byteArray.getBytes());
            response.getOutputStream().flush();
        } catch (IOException e) {
            log.error("文件下载失败: {}", e.getMessage(), e);
            throw new RuntimeException("文件下载失败", e);
        }
    }
}




